@@ -1,44 +1,46 @@
-/*-------------------------------------------------------------------------------------*/
-/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search - version 3.8.0      */
-/*                                                                                     */
-/*                                                                                     */
-/*  NOMAD - version 3.8.0 has been created by                                          */
-/*                 Charles Audet        - Ecole Polytechnique de Montreal              */
-/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
-/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
-/*                                                                                     */
-/*  The copyright of NOMAD - version 3.8.0 is owned by                                 */
-/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
-/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
-/*                                                                                     */
-/*  NOMAD v3 has been funded by AFOSR and Exxon Mobil.                                 */
-/*                                                                                     */
-/*  NOMAD v3 is a new version of NOMAD v1 and v2. NOMAD v1 and v2 were created and     */
-/*  developed by Mark Abramson, Charles Audet, Gilles Couture and John E. Dennis Jr.,  */
-/*  and were funded by AFOSR and Exxon Mobil.                                          */
-/*                                                                                     */
-/*                                                                                     */
-/*  Contact information:                                                               */
-/*    Ecole Polytechnique de Montreal - GERAD                                          */
-/*    C.P. 6079, Succ. Centre-ville, Montreal (Quebec) H3C 3A7 Canada                  */
-/*    e-mail: nomad@gerad.ca                                                           */
-/*    phone : 1-514-340-6053 #6928                                                     */
-/*    fax   : 1-514-340-5665                                                           */
-/*                                                                                     */
-/*  This program is free software: you can redistribute it and/or modify it under the  */
-/*  terms of the GNU Lesser General Public License as published by the Free Software   */
-/*  Foundation, either version 3 of the License, or (at your option) any later         */
-/*  version.                                                                           */
-/*                                                                                     */
-/*  This program is distributed in the hope that it will be useful, but WITHOUT ANY    */
-/*  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A    */
-/*  PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.   */
-/*                                                                                     */
-/*  You should have received a copy of the GNU Lesser General Public License along     */
-/*  with this program. If not, see <http://www.gnu.org/licenses/>.                     */
-/*                                                                                     */
-/*  You can find information on the NOMAD software at www.gerad.ca/nomad               */
-/*-------------------------------------------------------------------------------------*/
+/*---------------------------------------------------------------------------------*/
+/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search -                */
+/*                                                                                 */
+/*  NOMAD - version 3.9.1 has been created by                                      */
+/*                 Charles Audet               - Ecole Polytechnique de Montreal   */
+/*                 Sebastien Le Digabel        - Ecole Polytechnique de Montreal   */
+/*                 Viviane Rochon Montplaisir - Ecole Polytechnique de Montreal   */
+/*                 Christophe Tribes           - Ecole Polytechnique de Montreal   */
+/*                                                                                 */
+/*  The copyright of NOMAD - version 3.9.1 is owned by                             */
+/*                 Sebastien Le Digabel        - Ecole Polytechnique de Montreal   */
+/*                 Viviane Rochon Montplaisir - Ecole Polytechnique de Montreal   */
+/*                 Christophe Tribes           - Ecole Polytechnique de Montreal   */
+/*                                                                                 */
+/*  NOMAD v3 has been funded by AFOSR and Exxon Mobil.                             */
+/*                                                                                 */
+/*  NOMAD v3 is a new version of NOMAD v1 and v2. NOMAD v1 and v2 were created     */
+/*  and developed by Mark Abramson, Charles Audet, Gilles Couture, and John E.     */
+/*  Dennis Jr., and were funded by AFOSR and Exxon Mobil.                          */
+/*                                                                                 */
+/*  Contact information:                                                           */
+/*    Ecole Polytechnique de Montreal - GERAD                                      */
+/*    C.P. 6079, Succ. Centre-ville, Montreal (Quebec) H3C 3A7 Canada              */
+/*    e-mail: nomad@gerad.ca                                                       */
+/*    phone : 1-514-340-6053 #6928                                                 */
+/*    fax   : 1-514-340-5665                                                       */
+/*                                                                                 */
+/*  This program is free software: you can redistribute it and/or modify it        */
+/*  under the terms of the GNU Lesser General Public License as published by       */
+/*  the Free Software Foundation, either version 3 of the License, or (at your     */
+/*  option) any later version.                                                     */
+/*                                                                                 */
+/*  This program is distributed in the hope that it will be useful, but WITHOUT    */
+/*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or          */
+/*  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License    */
+/*  for more details.                                                              */
+/*                                                                                 */
+/*  You should have received a copy of the GNU Lesser General Public License       */
+/*  along with this program. If not, see <http://www.gnu.org/licenses/>.           */
+/*                                                                                 */
+/*  You can find information on the NOMAD software at www.gerad.ca/nomad           */
+/*---------------------------------------------------------------------------------*/
+
 /**
  \file   GMesh.cpp
  \brief  Class for the MADS xmesh (implementation)
@@ -49,6 +51,7 @@
 #include "GMesh.hpp"
 #include <math.h>
 
+const int HARD_MIN_MESH_INDEX = -300; // Below this limit creates issues.
 
 /*-----------------------------------------------------------*/
 /*                    init the GMesh                       */
@@ -72,12 +75,12 @@ void NOMAD::GMesh::init ( )
     }
     
     // Set the mesh mantissas and exponents
-    init_poll_size_granular ( Delta_Delta_0 );
+    init_poll_size_granular ( D_Delta_0 );
     
     // Update mesh and poll after granular sizing
-    Delta_Delta_0_exp = Delta_Delta_exp ;
-    Delta_Delta_0_mant = Delta_Delta_mant;
-    get_Delta ( Delta_Delta_0 );
+    D_Delta_0_exp = D_Delta_exp ;
+    D_Delta_0_mant = D_Delta_mant;
+    get_Delta ( D_Delta_0 );
     get_delta ( _delta_0 );
     
 
@@ -85,38 +88,6 @@ void NOMAD::GMesh::init ( )
 }
 
 
-/*-----------------------------------------------------------*/
-/* Update the provided mesh indices (the Mesh is unchanged). */
-/*-----------------------------------------------------------*/
-void NOMAD::GMesh::update ( NOMAD::success_type success ,
-                           NOMAD::Point & mesh_indices,
-                           const NOMAD::Direction *dir ) const
-{
-    
-    if ( mesh_indices.is_defined() )
-    {
-        
-        if ( dir && dir->size() != mesh_indices.size() )
-            throw NOMAD::Exception ( "GMesh.cpp" , __LINE__ ,
-                                    "NOMAD::GMesh::update(): mesh_indices and dir have different sizes" );
-        
-        for (int i=0; i < mesh_indices.size() ; i++)
-        {
-            if ( ! _fixed_variables.is_defined() && success == NOMAD::FULL_SUCCESS )
-            {
-                mesh_indices[i] ++;
-                
-                if ( mesh_indices[i] > -NOMAD::GL_LIMITS )
-                    mesh_indices[i] = -NOMAD::GL_LIMITS;
-            }
-            else if ( ! _fixed_variables.is_defined() && success == NOMAD::UNSUCCESSFUL )
-                mesh_indices[i] --;
-        }
-    }
-}
-
-
-
 /*-----------------------------------------------------------*/
 /*                    update the granular mesh                        */
 /*-----------------------------------------------------------*/
@@ -134,34 +105,31 @@ void NOMAD::GMesh::update ( NOMAD::success_type success , const NOMAD::Direction
         for ( int i=0 ; i < _n ;i++ )
         {
             if ( _granularity[i] == 0 && !_fixed_variables[i].is_defined() )
-                min_rho= NOMAD::min ( min_rho , get_rho(i));
+                min_rho=NOMAD::min ( min_rho , get_rho(i) );
         }
         
         for (int i=0 ; i < _n ; i++ )
         {
-            
             // Test for producing anisotropic mesh + correction to prevent mesh collapsing for some variables ( ifnot )
             if ( !_fixed_variables[i].is_defined() )
             {
-                
-
                 if ( ! d || ! _anisotropic_mesh ||
-                     fabs((*d)[i].value())/get_delta(i).value()/get_rho(i).value() > 0.1 ||
-                    ( _granularity[i] == 0  && Delta_Delta_exp[i] < Delta_Delta_0_exp[i] && get_rho(i) > min_rho*min_rho ))
+                     fabs((*d)[i].value())/get_delta(i).value()/get_rho(i).value() > _anisotropy_factor.value() ||
+                    ( _granularity[i] == 0  && D_Delta_exp[i] < D_Delta_0_exp[i] && get_rho(i) > min_rho*min_rho ))
                 {
                     // update the mesh index
                     ++_r[i];
-                    _r_max[i]= NOMAD::max(_r[i],_r_max[i]);
+                    _r_max[i]=NOMAD::max(_r[i],_r_max[i]);
                     
                     // update the mantissa and exponent
-                    if ( Delta_Delta_mant[i] == 1 )
-                        Delta_Delta_mant[i]= 2;
-                    else if ( Delta_Delta_mant[i] == 2 )
-                        Delta_Delta_mant[i]=5;
+                    if ( D_Delta_mant[i] == 1 )
+                        D_Delta_mant[i]= 2;
+                    else if ( D_Delta_mant[i] == 2 )
+                        D_Delta_mant[i]=5;
                     else
                     {
-                        Delta_Delta_mant[i]=1;
-                        ++Delta_Delta_exp[i];
+                        D_Delta_mant[i]=1;
+                        ++D_Delta_exp[i];
                     }
                 }
             }
@@ -178,22 +146,22 @@ void NOMAD::GMesh::update ( NOMAD::success_type success , const NOMAD::Direction
                 --_r[i];
                 
                 // update the mesh mantissa and exponent
-                if ( Delta_Delta_mant[i] == 1 )
+                if ( D_Delta_mant[i] == 1 )
                 {
-                    Delta_Delta_mant[i]= 5;
-                    --Delta_Delta_exp[i];
+                    D_Delta_mant[i]= 5;
+                    --D_Delta_exp[i];
                 }
-                else if ( Delta_Delta_mant[i] == 2 )
-                    Delta_Delta_mant[i]=1;
+                else if ( D_Delta_mant[i] == 2 )
+                    D_Delta_mant[i]=1;
                 else
-                    Delta_Delta_mant[i]=2;
+                    D_Delta_mant[i]=2;
                 
                 
-                if ( _granularity[i] > 0 && Delta_Delta_exp[i]==-1 && Delta_Delta_mant[i]==5 )
+                if ( _granularity[i] > 0 && D_Delta_exp[i]==-1 && D_Delta_mant[i]==5 )
                 {
                     ++_r[i];
-                    Delta_Delta_exp[i]=0;
-                    Delta_Delta_mant[i]=1;
+                    D_Delta_exp[i]=0;
+                    D_Delta_mant[i]=1;
                 }
             }
             // Update the minimal mesh index reached so far
@@ -220,14 +188,14 @@ void NOMAD::GMesh::display ( const NOMAD::Display & out ) const
         out << "none";
     out << std::endl
     << "minimal poll size       : ";
-    if ( Delta_Delta_min_is_defined )
-        out << "( " << Delta_Delta_min     << " )" << std::endl;
+    if ( D_Delta_min_is_defined )
+        out << "( " << D_Delta_min     << " )" << std::endl;
     else
         out << "none";
     
     out << std::endl << "initial poll size       : ";
-    if ( Delta_Delta_0.is_defined() )
-        out <<"( " << Delta_Delta_0     << " )" << std::endl;
+    if ( D_Delta_0.is_defined() )
+        out <<"( " << D_Delta_0     << " )" << std::endl;
     else
         out <<"( none )" << std::endl;
     
@@ -249,7 +217,6 @@ void NOMAD::GMesh::display ( const NOMAD::Display & out ) const
 void NOMAD::GMesh::check_min_mesh_sizes ( bool             & stop           ,
                                          NOMAD::stop_type & stop_reason      ) const
 {
-    
     if ( stop )
         return;
     
@@ -270,27 +237,34 @@ void NOMAD::GMesh::check_min_mesh_sizes ( bool             & stop           ,
 
     stop=true;
 
-    // Fine mesh stopping criterion (do not apply when all variables have granularity
-    // All mesh indices must < _limit_mesh_index for all continuous variables (granularity==0) and
-    // and mesh size = granularity for all granular variables to trigger this stopping criterion
+    // Fine mesh stopping criterion. Do not apply when all variables have granularity.
+    // To trigger this stopping criterion:
+    //  - All mesh indices must be < _limit_mesh_index for all continuous variables (granularity==0), and
+    //  - mesh size == granularity for all granular variables.
     if ( _all_granular )
     {
-        // Do not stop because of to fine a mesh if all variables are granular
-        stop =false;
+        // Do not stop because of too fine a mesh if all non-fixed variables are granular.
+        stop = false;
     }
     else
     {
         for ( int i=0 ; i <_n ; i++ )
         {
+            // Skip fixed variables
+            if (_fixed_variables[i].is_defined())
+            {
+                continue;
+            }
+
             // Do not stop if the mesh size of a variable is strictly larger than its granularity
-            if ( _granularity[i] > 0 && ! _fixed_variables[i].is_defined() && get_delta(i) > _granularity[i] )
+            if ( _granularity[i] > 0 && get_delta(i) > _granularity[i] )
             {
                 stop = false;
                 break;
             }
             
             // Do not stop if the mesh of a variable is above the limit mesh index
-            if ( _granularity[i] == 0 && ! _fixed_variables[i].is_defined() && _r[i] >= _limit_mesh_index )
+            if ( _granularity[i] == 0 && _r[i] >= _limit_mesh_index )
             {
                 stop = false;
                 break;
@@ -326,7 +300,7 @@ void NOMAD::GMesh::check_min_mesh_sizes ( bool             & stop           ,
 /*-----------------------------------------------------------*/
 bool NOMAD::GMesh::check_min_poll_size_criterion ( ) const
 {
-    if ( !Delta_Delta_min_is_defined )
+    if ( !D_Delta_min_is_defined )
         return false;
     
     NOMAD::Point Delta;
@@ -380,7 +354,7 @@ NOMAD::Double NOMAD::GMesh::get_delta ( int i ) const
 {
     
     
-    NOMAD::Double delta = pow ( 10 , Delta_Delta_exp[i].value() - std::fabs( Delta_Delta_exp[i].value() - Delta_Delta_0_exp[i].value() ) );
+    NOMAD::Double delta = pow ( 10 , D_Delta_exp[i].value() - std::fabs( D_Delta_exp[i].value() - D_Delta_0_exp[i].value() ) );
     
     if ( _granularity[i] > 0 )
         delta = _granularity[i] * NOMAD::max( 1.0 , delta );
@@ -401,7 +375,7 @@ NOMAD::Double NOMAD::GMesh::get_Delta ( int i ) const
     if ( _granularity[i] > 0 )
         d_min_gran = _granularity[i];
     
-    NOMAD::Double Delta = d_min_gran * Delta_Delta_mant[i] * pow ( 10.0, Delta_Delta_exp[i].value() ) ;
+    NOMAD::Double Delta = d_min_gran * D_Delta_mant[i] * pow ( 10.0, D_Delta_exp[i].value() ) ;
     
     return Delta;
 }
@@ -425,10 +399,10 @@ bool NOMAD::GMesh::get_Delta ( NOMAD::Point & Delta ) const
     {
         Delta[i] = get_Delta( i );
         
-        if (  stop && ! _fixed_variables[i].is_defined() && _granularity[i] == 0 && ( !Delta_Delta_min_is_complete  || Delta[i] >= Delta_Delta_min[i] ) )
+        if (  stop && ! _fixed_variables[i].is_defined() && _granularity[i] == 0 && ( !D_Delta_min_is_complete  || Delta[i] >= D_Delta_min[i] ) )
             stop = false;
         
-        if ( stop && ! _fixed_variables[i].is_defined() && _granularity[i] > 0 && ( !Delta_Delta_min_is_complete  || Delta[i] > Delta_Delta_min[i] ) )
+        if ( stop && ! _fixed_variables[i].is_defined() && _granularity[i] > 0 && ( !D_Delta_min_is_complete  || Delta[i] > D_Delta_min[i] ) )
             stop = false;
 
     }
@@ -443,12 +417,16 @@ bool NOMAD::GMesh::get_Delta ( NOMAD::Point & Delta ) const
 /*--------------------------------------------------------------*/
 NOMAD::Double NOMAD::GMesh::get_rho ( int i ) const
 {
+
     NOMAD::Double rho ;
     if ( _granularity[i] > 0  )
-        rho = Delta_Delta_mant[i] * min( pow ( 10 , Delta_Delta_exp[i].value() ) , pow ( 10 , std::fabs( Delta_Delta_exp[i].value() - Delta_Delta_0_exp[i].value() ) ) );
+    {
+        rho = D_Delta_mant[i] * NOMAD::min( pow ( 10 , D_Delta_exp[i].value() ) , pow ( 10 , std::fabs( D_Delta_exp[i].value() - D_Delta_0_exp[i].value() ) ) );
+    }
     else
-        rho = Delta_Delta_mant[i] * pow ( 10 , std::fabs( Delta_Delta_exp[i].value() - Delta_Delta_0_exp[i].value() ) );
-    
+    {
+        rho = D_Delta_mant[i] * pow ( 10 , std::fabs( D_Delta_exp[i].value() - D_Delta_0_exp[i].value() ) );
+    }
 
     return rho;
     
@@ -476,6 +454,11 @@ void NOMAD::GMesh::set_mesh_indices ( const NOMAD::Point & r )
     if ( r.size() != _n )
         throw NOMAD::Exception ( "GMesh.cpp" , __LINE__ ,
                                 "NOMAD::GMesh::set_mesh_indices(): dimension of provided mesh indices must be consistent with their previous dimension" );
+
+    if (r[0] < HARD_MIN_MESH_INDEX)
+    {
+        throw NOMAD::Exception(__FILE__,__LINE__, "NOMAD::GMesh::set_mesh_indices(): mesh index is too small");
+    }
     
     // Set the mesh indices
     _r=r;
@@ -493,14 +476,15 @@ void NOMAD::GMesh::set_mesh_indices ( const NOMAD::Point & r )
         int shift = static_cast<int>( _r[i].value() + _pos_mant_0[i].value() );
         int pos= ( shift + 300 )  % 3 ;
         
-        Delta_Delta_exp[i] = std::floor( ( shift + 300.0 )/3.0 ) - 100.0 + Delta_Delta_0_exp[i];
+        D_Delta_exp[i] = std::floor( ( shift + 300.0 )/3.0 ) - 100.0 + D_Delta_0_exp[i];
+        // _Delta_exp[i] = (int)( (_r[i].value() + _pos_mant_0[i].value() )/3.0) + _Delta_0_exp[i];
         
         if ( pos == 0 )
-            Delta_Delta_mant[i] = 1;
+            D_Delta_mant[i] = 1;
         else if ( pos == 1 )
-            Delta_Delta_mant[i] = 2;
+            D_Delta_mant[i] = 2;
         else if ( pos == 2 )
-            Delta_Delta_mant[i] = 5;
+            D_Delta_mant[i] = 5;
         else
             throw NOMAD::Exception ( "GMesh.cpp" , __LINE__ ,
                                     "NOMAD::GMesh::set_mesh_indices(): something is wrong with conversion from index to mantissa and exponent" );
@@ -515,8 +499,15 @@ void NOMAD::GMesh::set_mesh_indices ( const NOMAD::Point & r )
 void NOMAD::GMesh::set_limit_mesh_index ( int l )
 {
     if ( l > 0 )
+    {
         throw NOMAD::Exception ( "GMesh.cpp" , __LINE__ ,
                                 "NOMAD::GMesh::set_limit_mesh_index(): the limit mesh index must be negative or null." );
+    }
+    if ( l < HARD_MIN_MESH_INDEX )
+    {
+        throw NOMAD::Exception ( "GMesh.cpp" , __LINE__ ,
+                                "NOMAD::GMesh::set_limit_mesh_index(): the limit mesh index is too small." );
+    }
     _limit_mesh_index=l;
 }
 
@@ -532,13 +523,14 @@ NOMAD::Double NOMAD::GMesh::scale_and_project(int i, const NOMAD::Double & l, bo
     
     NOMAD::Double delta = get_delta( i );
     
-    if ( i <= _n && Delta_Delta_mant.is_defined() && Delta_Delta_exp.is_defined() && delta.is_defined() )
+    if ( i <= _n && D_Delta_mant.is_defined() && D_Delta_exp.is_defined() && delta.is_defined() )
     {
         NOMAD::Double d = get_rho(i) * l;
+        
+        // round to double instead of Nomad round to int
         return d.roundd() * delta;
     }
     else
-        
         throw NOMAD::Exception ( "GMesh.cpp" , __LINE__ ,
                                 "NOMAD::GMesh::scale_and_project(): mesh scaling and projection cannot be performed!" );
     
@@ -581,8 +573,8 @@ void NOMAD::GMesh::init_poll_size_granular ( NOMAD::Point & cont_init_poll_size
         throw NOMAD::Exception ( "GMesh.cpp" , __LINE__ ,
                                 "NOMAD::GMesh::init_poll_size_granular(): Inconsistent dimension of the poll size!" );
     
-    Delta_Delta_exp.reset ( _n );
-    Delta_Delta_mant.reset ( _n );
+    D_Delta_exp.reset ( _n );
+    D_Delta_mant.reset ( _n );
     _pos_mant_0.reset ( _n );
     
     
@@ -597,24 +589,30 @@ void NOMAD::GMesh::init_poll_size_granular ( NOMAD::Point & cont_init_poll_size
             d_min=1.0;
         
         int exp= (int)( std::log10( std::fabs( cont_init_poll_size[i].value()/d_min.value() )));
-        Delta_Delta_exp[i]=exp;
+        
+        // The poll size cannot be smaller than the granularity
+        // Hence, the initial exponant must >= 0 
+        if ( exp < 0 )
+            exp = 0;
+        
+        D_Delta_exp[i]=exp;
         
         double cont_mant = cont_init_poll_size[i].value() / d_min.value() * pow ( 10.0 , -exp );
         
         // round to 1, 2 or 5
         if ( cont_mant < 1.5 )
         {
-            Delta_Delta_mant[i]=1;
+            D_Delta_mant[i]=1;
             _pos_mant_0[i]=0;
         }
         else if ( cont_mant >= 1.5 && cont_mant < 3.5 )
         {
-            Delta_Delta_mant[i]=2;
+            D_Delta_mant[i]=2;
             _pos_mant_0[i]=1;
         }
         else
         {
-            Delta_Delta_mant[i]=5;
+            D_Delta_mant[i]=5;
             _pos_mant_0[i]=2;
         }
     }
@@ -627,22 +625,24 @@ bool NOMAD::GMesh::is_finer_than_initial (void) const
     
     for (int i =0; i < _n ; ++i )
     {
+        
         if ( !_fixed_variables[i].is_defined() )
         {
             
             // For continuous variables
-            if ( _granularity[i]==0 && ( Delta_Delta_exp[i] > Delta_Delta_0_exp[i] || ( Delta_Delta_exp[i] == Delta_Delta_0_exp[i] && Delta_Delta_mant[i] >= Delta_Delta_0_mant[i] ) ) )
+            if ( _granularity[i]==0 && ( D_Delta_exp[i] > D_Delta_0_exp[i] || ( D_Delta_exp[i] == D_Delta_0_exp[i] && D_Delta_mant[i] >= D_Delta_0_mant[i] ) ) )
                 return false;
             
             // For granular variables ( case 1 )
-            if ( _granularity[i] > 0 && ( Delta_Delta_exp[i] > Delta_Delta_0_exp[i] || ( Delta_Delta_exp[i] == Delta_Delta_0_exp[i] && Delta_Delta_mant[i] > Delta_Delta_0_mant[i] ) ) )
+            if ( _granularity[i] > 0 && ( D_Delta_exp[i] > D_Delta_0_exp[i] || ( D_Delta_exp[i] == D_Delta_0_exp[i] && D_Delta_mant[i] > D_Delta_0_mant[i] ) ) )
                 return false;
             
             // For granular variables ( case 2 )
-            if ( _granularity[i] > 0 && Delta_Delta_exp[i] == Delta_Delta_0_exp[i] && Delta_Delta_mant[i] == Delta_Delta_0_mant[i] && ( Delta_Delta_exp[i] != 0 ||  Delta_Delta_mant[i] != 1 ) )
+            if ( _granularity[i] > 0 && D_Delta_exp[i] == D_Delta_0_exp[i] && D_Delta_mant[i] == D_Delta_0_mant[i] && ( D_Delta_exp[i] != 0 ||  D_Delta_mant[i] != 1 ) )
                 return false;
         }
         
+        
     }
     
     return true;
