@@ -1,44 +1,46 @@
-/*-------------------------------------------------------------------------------------*/
-/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search - version 3.8.0      */
-/*                                                                                     */
-/*                                                                                     */
-/*  NOMAD - version 3.8.0 has been created by                                          */
-/*                 Charles Audet        - Ecole Polytechnique de Montreal              */
-/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
-/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
-/*                                                                                     */
-/*  The copyright of NOMAD - version 3.8.0 is owned by                                 */
-/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
-/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
-/*                                                                                     */
-/*  NOMAD v3 has been funded by AFOSR and Exxon Mobil.                                 */
-/*                                                                                     */
-/*  NOMAD v3 is a new version of NOMAD v1 and v2. NOMAD v1 and v2 were created and     */
-/*  developed by Mark Abramson, Charles Audet, Gilles Couture and John E. Dennis Jr.,  */
-/*  and were funded by AFOSR and Exxon Mobil.                                          */
-/*                                                                                     */
-/*                                                                                     */
-/*  Contact information:                                                               */
-/*    Ecole Polytechnique de Montreal - GERAD                                          */
-/*    C.P. 6079, Succ. Centre-ville, Montreal (Quebec) H3C 3A7 Canada                  */
-/*    e-mail: nomad@gerad.ca                                                           */
-/*    phone : 1-514-340-6053 #6928                                                     */
-/*    fax   : 1-514-340-5665                                                           */
-/*                                                                                     */
-/*  This program is free software: you can redistribute it and/or modify it under the  */
-/*  terms of the GNU Lesser General Public License as published by the Free Software   */
-/*  Foundation, either version 3 of the License, or (at your option) any later         */
-/*  version.                                                                           */
-/*                                                                                     */
-/*  This program is distributed in the hope that it will be useful, but WITHOUT ANY    */
-/*  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A    */
-/*  PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.   */
-/*                                                                                     */
-/*  You should have received a copy of the GNU Lesser General Public License along     */
-/*  with this program. If not, see <http://www.gnu.org/licenses/>.                     */
-/*                                                                                     */
-/*  You can find information on the NOMAD software at www.gerad.ca/nomad               */
-/*-------------------------------------------------------------------------------------*/
+/*---------------------------------------------------------------------------------*/
+/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search -                */
+/*                                                                                 */
+/*  NOMAD - version 3.9.1 has been created by                                      */
+/*                 Charles Audet               - Ecole Polytechnique de Montreal   */
+/*                 Sebastien Le Digabel        - Ecole Polytechnique de Montreal   */
+/*                 Viviane Rochon Montplaisir - Ecole Polytechnique de Montreal   */
+/*                 Christophe Tribes           - Ecole Polytechnique de Montreal   */
+/*                                                                                 */
+/*  The copyright of NOMAD - version 3.9.1 is owned by                             */
+/*                 Sebastien Le Digabel        - Ecole Polytechnique de Montreal   */
+/*                 Viviane Rochon Montplaisir - Ecole Polytechnique de Montreal   */
+/*                 Christophe Tribes           - Ecole Polytechnique de Montreal   */
+/*                                                                                 */
+/*  NOMAD v3 has been funded by AFOSR and Exxon Mobil.                             */
+/*                                                                                 */
+/*  NOMAD v3 is a new version of NOMAD v1 and v2. NOMAD v1 and v2 were created     */
+/*  and developed by Mark Abramson, Charles Audet, Gilles Couture, and John E.     */
+/*  Dennis Jr., and were funded by AFOSR and Exxon Mobil.                          */
+/*                                                                                 */
+/*  Contact information:                                                           */
+/*    Ecole Polytechnique de Montreal - GERAD                                      */
+/*    C.P. 6079, Succ. Centre-ville, Montreal (Quebec) H3C 3A7 Canada              */
+/*    e-mail: nomad@gerad.ca                                                       */
+/*    phone : 1-514-340-6053 #6928                                                 */
+/*    fax   : 1-514-340-5665                                                       */
+/*                                                                                 */
+/*  This program is free software: you can redistribute it and/or modify it        */
+/*  under the terms of the GNU Lesser General Public License as published by       */
+/*  the Free Software Foundation, either version 3 of the License, or (at your     */
+/*  option) any later version.                                                     */
+/*                                                                                 */
+/*  This program is distributed in the hope that it will be useful, but WITHOUT    */
+/*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or          */
+/*  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License    */
+/*  for more details.                                                              */
+/*                                                                                 */
+/*  You should have received a copy of the GNU Lesser General Public License       */
+/*  along with this program. If not, see <http://www.gnu.org/licenses/>.           */
+/*                                                                                 */
+/*  You can find information on the NOMAD software at www.gerad.ca/nomad           */
+/*---------------------------------------------------------------------------------*/
+
 /**
  \file   Mads.hpp
  \brief  MADS algorithm (headers)
@@ -55,6 +57,8 @@
 #include "VNS_Search.hpp"
 #include "Cache_Search.hpp"
 #include "Phase_One_Search.hpp"
+#include "NelderMead_Search.hpp"
+#include "TrendMatrix_Line_Search.hpp"
 #include "L_Curve.hpp"
 #include "Extended_Poll.hpp"
 
@@ -67,7 +71,7 @@ namespace NOMAD {
     class Extended_Poll;
     
     /// The MADS algorithm.
-    class Mads : private NOMAD::Uncopyable {
+    class DLL_API Mads : private NOMAD::Uncopyable {
         
     private:
         
@@ -92,7 +96,7 @@ namespace NOMAD {
         NOMAD::Search        * _model_search1;  ///< Model search #1.
         NOMAD::Search        * _model_search2;  ///< Model search #2.
         
-        NOMAD::Search        * VNS_VNS_search;     ///< VNS search.   ///zhenghua, for compiling on Solaris.
+        NOMAD::Search        * VNS_VNS_search;     ///< VNS search.  zhenghua
         NOMAD::Search        * _cache_search;   ///< Cache search.
         NOMAD::L_Curve       * L_L_curve;        ///< L-curve target.
         NOMAD::Extended_Poll * _extended_poll;  ///< Extended poll for categorical variables.
@@ -159,12 +163,12 @@ namespace NOMAD {
          size stopping criterion has to be
          disabled for integer variables -- \b OUT.
          */
-        void poll ( bool					& stop,
-                   NOMAD::stop_type		& stop_reason,
-                   NOMAD::success_type		& success,
+        void poll ( bool                    & stop,
+                   NOMAD::stop_type         & stop_reason,
+                   NOMAD::success_type      & success,
                    const NOMAD::Eval_Point *& new_feas_inc,
                    const NOMAD::Eval_Point *& new_infeas_inc,
-                   bool					& forbid_poll_size_stop   );
+                   bool                     & forbid_poll_size_stop   );
         
         /// Sets the poll trial points from poll direction, poll center and mesh size
         /**
@@ -177,10 +181,10 @@ namespace NOMAD {
          */
         void set_poll_trial_points (  std::list<NOMAD::Direction> & dirs,
                                     size_t                           offset,
-                                    const NOMAD::Eval_Point     &  poll_center,
-                                    bool					    	& stop,
-                                    NOMAD::stop_type				&stop_reason,
-                                    bool							sorting);
+                                    const NOMAD::Eval_Point       &  poll_center,
+                                    bool                          & stop,
+                                    NOMAD::stop_type              & stop_reason,
+                                    bool                            sorting );
         
         
         /// Compute a prospect point by optimization on quadratic models.
@@ -197,12 +201,12 @@ namespace NOMAD {
         
         /// Sets the poll directions from signature, poll center and mesh size
         /**
-         \param dirs			List of directions for the poll			          -- \b OUT.
-         \param i_pc			Poll type                                         -- \b IN.
+         \param dirs            List of directions for the poll                   -- \b OUT.
+         \param i_pc            Poll type                                         -- \b IN.
          \param offset          Dir index offset for primary and sec. poll center -- \b IN.
          \param poll_center     The poll center                                   -- \b IN.
-         \param stop 			Stop flag, true if cannot get direction   		  -- \b IN/OUT.
-         \param stop_reason	Stop type										  -- \b OUT.
+         \param stop            Stop flag, true if cannot get direction           -- \b IN/OUT.
+         \param stop_reason     Stop type                                         -- \b OUT.
          */
         void set_poll_directions ( std::list<NOMAD::Direction> & dirs        ,
                                   NOMAD::poll_type              i_pc        ,
@@ -216,22 +220,22 @@ namespace NOMAD {
         /**
          \param poll_center     The poll center                                   -- \b IN.
          \param offset          Dir index offset for intensification              -- \b IN.
-         \param stop            Stop flag, true if cannot get direction   		  -- \b IN/OUT.
-         \param stop_reason     Stop type										  -- \b OUT.
+         \param stop            Stop flag, true if cannot get direction           -- \b IN/OUT.
+         \param stop_reason     Stop type                                         -- \b OUT.
          */
         void set_poll_intensification_points ( const NOMAD::Eval_Point     & poll_center,
                                               size_t  &                      offset      ,
                                               bool                        & stop        ,
-                                              NOMAD::stop_type            & stop_reason   );
+                                              NOMAD::stop_type            & stop_reason  );
         
         /// Reduce the number of poll directions -> n
         /**
-         \param dirs			List of directions for the poll			-- \b IN/OUT.
-         \param  poll_center   the poll center                         -- \b IN.
+         \param dirs            List of directions for the poll         -- \b IN/OUT.
+         \param poll_center     the poll center                         -- \b IN.
          \return success for this step.
          */
-        bool set_reduced_poll_to_n_directions(std::list<NOMAD::Direction>	& dirs,
-                                              const NOMAD::Eval_Point		& poll_center);
+        bool set_reduced_poll_to_n_directions(std::list<NOMAD::Direction>   & dirs,
+                                              const NOMAD::Eval_Point       & poll_center);
         
         /// Compute the rank of a list of directions
         /**
@@ -318,13 +322,13 @@ namespace NOMAD {
         /**
          - The computed opposite directions already include Delta^k_m.
          \param dirs          List of existing directions (no snap to bounds) -- \b IN.
-         \param newDirs		New dynamic directions              -- \b OUT.
+         \param newDirs     New dynamic directions              -- \b OUT.
          \param poll_center   Poll center                         -- \b IN.
          \return true if new dynamic direction generated false otherwise
          */
-        bool get_dynamic_directions (const std::list<NOMAD::Direction>	&	dirs,
-                                     std::list<NOMAD::Direction>			&	newDirs,
-                                     const NOMAD::Eval_Point				&	poll_center) ;
+        bool get_dynamic_directions (const std::list<NOMAD::Direction>  & dirs,
+                                     std::list<NOMAD::Direction>        & newDirs,
+                                     const NOMAD::Eval_Point            & poll_center) ;
         
         
         
@@ -348,12 +352,12 @@ namespace NOMAD {
         
         /// get a single direction using quad model optimization or sum of negatives
         /**
-         \param dirs			Reduced poll directions	(no snap to bounds)	-- \b IN.
-         \param poll_center	Poll center								    -- \b IN.
+         \param dirs            Reduced poll directions (no snap to bounds) -- \b IN.
+         \param poll_center Poll center                                 -- \b IN.
          \return new direction
          */
-        NOMAD::Direction get_single_dynamic_direction (const std::list<NOMAD::Direction>	&	dirs,
-                                                       const NOMAD::Eval_Point			&	poll_center) ;
+        NOMAD::Direction get_single_dynamic_direction (const std::list<NOMAD::Direction>    & dirs,
+                                                       const NOMAD::Eval_Point              & poll_center) ;
         
         
         /*-----------------------------------------------------------------------------*/
@@ -374,7 +378,7 @@ namespace NOMAD {
         _ev_control_for_sorting( p , _stats , _ev_control.get_evaluator() , &(_ev_control.get_cache()) , &(_ev_control.get_sgte_cache()) ) ,
         _true_barrier          ( p , NOMAD::TRUTH              ) ,
         _sgte_barrier          ( p , NOMAD::SGTE               ) ,
-        _mesh				   ( p.get_signature()->get_mesh() ) ,
+        _mesh                  ( p.get_signature()->get_mesh() ) ,
         _pareto_front          ( NULL                          ) ,
         _user_search           ( NULL                          ) ,
         _model_search1         ( NULL                          ) ,
@@ -408,7 +412,7 @@ namespace NOMAD {
         _ev_control_for_sorting( p , _stats , _ev_control.get_evaluator() , cache , sgte_cache ) ,
         _true_barrier          ( p , NOMAD::TRUTH                     ) ,
         _sgte_barrier          ( p , NOMAD::SGTE                      ) ,
-        _mesh                  ( p.get_signature()->get_mesh()		  ) ,
+        _mesh                  ( p.get_signature()->get_mesh()        ) ,
         _pareto_front          ( NULL                                 ) ,
         _user_search           ( NULL                                 ) ,
         _model_search1         ( NULL                                 ) ,
